==> openejb-core-4.5.1-sources.jar: org/apache/openejb/core/timer/ScheduleData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.core.timer;

import javax.ejb.ScheduleExpression;
import javax.ejb.TimerConfig;

/**
 * Simple object to hold the ScheduleExpression and TimerConfig pair
 *
 * Zero or many of these may be associated with a method and available
 * via the MethodSchedule list retrieved from the DeploymentInfo
 *
 * @version $Rev: 1153797 $ $Date: 2011-08-04 11:09:44 +0200 (Jeu, 04 aoû 2011) $
 * 
 */
public class ScheduleData {

    private final ScheduleExpression expression;
    private final TimerConfig config;

    public ScheduleData(TimerConfig config, ScheduleExpression expression) {
        this.config = config;
        this.expression = expression;
    }

    public TimerConfig getConfig() {
        return config;
    }

    public ScheduleExpression getExpression() {
        return expression;
    }
}

==> openejb-core-4.7.1-sources.jar: org/apache/openejb/core/timer/ScheduleData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.core.timer;

import javax.ejb.ScheduleExpression;
import javax.ejb.TimerConfig;

/**
 * Simple object to hold the ScheduleExpression and TimerConfig pair
 * <p/>
 * Zero or many of these may be associated with a method and available
 * via the MethodSchedule list retrieved from the DeploymentInfo
 *
 * @version $Rev: 1607852 $ $Date: 2014-07-04 15:32:03 +0200 (Fri, 04 Jul 2014) $
 */
public class ScheduleData {

    private final ScheduleExpression expression;
    private final TimerConfig config;

    public ScheduleData(final TimerConfig config, final ScheduleExpression expression) {
        this.config = config;
        this.expression = expression;
    }

    public TimerConfig getConfig() {
        return config;
    }

    public ScheduleExpression getExpression() {
        return expression;
    }
}
